@@ -89,6 +89,7 @@ def create_function(
         logging.debug(f"Deleted function {function_name}")
     except CogniteNotFoundError:
         pass
+    env_vars = {k.upper():v for k,v in config.getenv.items()}
     function = client.functions.create( 
         name=function_name, 
         folder=folder, 
@@ -97,7 +98,7 @@ def create_function(
         description=description,
         owner=owner,
         secrets=secrets,
-        env_vars=config.getenv
+        env_vars=env_vars
     )
     logging.debug(
         f"Created {function_name}: {folder=}, {handler_path=}"
