@@ -89,8 +89,7 @@ def run_container(image_name, service_account):
     Run container with a service account
     """
     logging.info(f"Run container, {image_name=}, {service_account=}")
-    envs = config.getenv.keys()
-    envs = [f"{e}={eval(e)}" for e in envs]
+    envs = [f"{k.upper()}={v}" for k,v in config.getenv.items()]
     env_list_string=','.join(envs)
     
     subprocess.check_call(
